import type { TokenType } from '../../types'
import React from 'react'
import { Platform, StyleSheet, Text, View } from 'react-native'

const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace',
})

const styles = StyleSheet.create({
  lineContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
  token: {
    includeFontPadding: false,
  },
})

interface SyntaxLineProps {
  line: TokenType[]
  fontSize?: number
}

function SyntaxLine({ line, fontSize = 14 }: SyntaxLineProps) {
  const lineHeight = fontSize * 1.5

  return (
    <View
      style={[
        styles.lineContainer,
        {
          minHeight: lineHeight,
        },
      ]}
    >
      {line.map((token, tokenIndex) => {
        const content = token.content.replace(/ /g, '\u00A0')
        return (
          <Text
            key={`${tokenIndex}-${content.slice(0, 8)}`}
            style={[
              styles.token,
              {
                color: token.color || '#FFFFFF',
                fontFamily: monospaceFont,
                fontSize,
                fontStyle: token.fontStyle as 'normal' | 'italic',
                fontWeight: token.fontWeight as 'normal' | 'bold',
                lineHeight,
                ...(Platform.OS === 'ios'
                  ? {
                      paddingTop: 1,
                    }
                  : {}),
              },
            ]}
          >
            {content}
          </Text>
        )
      })}
    </View>
  )
}

export default SyntaxLine
